Kreveik
=======

Kreveik is a Python module for Boolean networks. With Kreveik, 
one can build Boolean networks, create random Boolean networks, 
investigate dynamics of these networks, form families of them, 
investigate macroscopic variables and expose them to genetic 
algorithms.


Production
----------

Right now, Kreveik is still in its production phase. Though bits and 
pieces of the code are in good condition, the whole wont give a seamless 
experience at all. 

Looking for contributors, preferably someone that will make use of the code.
contact:mehmet.ali.anil@ieee.org
 